DROP TABLE IF EXISTS "als"."als_air_configuration_t";
CREATE TABLE "als"."als_air_configuration_t"(
                                                id bigint NOT NULL,
                                                aircraft_type VARCHAR2(255),
                                                con_code VARCHAR2(255),
                                                name VARCHAR2(255),
                                                specs_model VARCHAR2(255),
                                                drawing_number VARCHAR2(255),
                                                supplier VARCHAR2(255),
                                                remarks VARCHAR2(900),
                                                tenant_id VARCHAR2,
                                                del_flag bit DEFAULT  0,
                                                version INTEGER,
                                                created_by VARCHAR2,
                                                created_time TIMESTAMP,
                                                updated_by VARCHAR2,
                                                updated_time TIMESTAMP
);

ALTER TABLE "als"."als_air_configuration_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_air_configuration_t" IS '飞机构型';
COMMENT ON COLUMN "als"."als_air_configuration_t"."id" IS '唯一ID';
COMMENT ON COLUMN "als"."als_air_configuration_t"."aircraft_type" IS '机型';
COMMENT ON COLUMN "als"."als_air_configuration_t"."con_code" IS '构型编码';
COMMENT ON COLUMN "als"."als_air_configuration_t"."name" IS '产品名称';
COMMENT ON COLUMN "als"."als_air_configuration_t"."specs_model" IS '规格型号';
COMMENT ON COLUMN "als"."als_air_configuration_t"."drawing_number" IS '图号';
COMMENT ON COLUMN "als"."als_air_configuration_t"."supplier" IS '供应商';
COMMENT ON COLUMN "als"."als_air_configuration_t"."remarks" IS '描述';
COMMENT ON COLUMN "als"."als_air_configuration_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_air_configuration_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_air_configuration_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_air_configuration_t"."created_by" IS '创建人';
COMMENT ON COLUMN "als"."als_air_configuration_t"."created_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_air_configuration_t"."updated_by" IS '更新人';
COMMENT ON COLUMN "als"."als_air_configuration_t"."updated_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_case_t";
CREATE TABLE "als"."als_fault_case_t"(
                                         id bigint NOT NULL,
                                         aircraft_type VARCHAR2(255),
                                         fault_code VARCHAR2(255),
                                         fault_name VARCHAR2(255),
                                         location VARCHAR2(255),
                                         level VARCHAR2(255),
                                         symptoms VARCHAR2(255),
                                         fault_cause VARCHAR2(255),
                                         remarks VARCHAR2(900),
                                         tenant_id bigint,
                                         version INTEGER,
                                         del_flag bit DEFAULT  0,
                                         create_by bigint,
                                         create_time TIMESTAMP,
                                         update_by bigint,
                                         update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_case_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_case_t" IS '故障案例';
COMMENT ON COLUMN "als"."als_fault_case_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_case_t"."aircraft_type" IS '机型';
COMMENT ON COLUMN "als"."als_fault_case_t"."fault_code" IS '故障代码';
COMMENT ON COLUMN "als"."als_fault_case_t"."fault_name" IS '故障名称';
COMMENT ON COLUMN "als"."als_fault_case_t"."location" IS '故障位置';
COMMENT ON COLUMN "als"."als_fault_case_t"."level" IS '故障等级';
COMMENT ON COLUMN "als"."als_fault_case_t"."symptoms" IS '故障现象';
COMMENT ON COLUMN "als"."als_fault_case_t"."fault_cause" IS '故障原因';
COMMENT ON COLUMN "als"."als_fault_case_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_case_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_case_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_case_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_case_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_case_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_case_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_case_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_setps_t";
CREATE TABLE "als"."als_fault_setps_t"(
                                          id bigint NOT NULL,
                                          setps INTEGER,
                                          method VARCHAR2(1500),
                                          image VARCHAR2(255),
                                          remarks VARCHAR2(900),
                                          tenant_id bigint,
                                          version INTEGER,
                                          del_flag bit DEFAULT  0,
                                          create_by bigint,
                                          create_time TIMESTAMP,
                                          update_by bigint,
                                          update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_setps_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_setps_t" IS '故障操作步骤';
COMMENT ON COLUMN "als"."als_fault_setps_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_setps_t"."setps" IS '操作步骤';
COMMENT ON COLUMN "als"."als_fault_setps_t"."method" IS '操作方法';
COMMENT ON COLUMN "als"."als_fault_setps_t"."image" IS '图片';
COMMENT ON COLUMN "als"."als_fault_setps_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_setps_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_setps_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_setps_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_setps_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_setps_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_setps_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_setps_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_personnel_t";
CREATE TABLE "als"."als_fault_personnel_t"(
                                              id bigint NOT NULL,
                                              personnel VARCHAR2(255),
                                              position VARCHAR2(900),
                                              quantity INTEGER,
                                              duties VARCHAR2(255),
                                              remarks VARCHAR2(900),
                                              tenant_id bigint,
                                              version INTEGER,
                                              del_flag bit DEFAULT  0,
                                              create_by bigint,
                                              create_time TIMESTAMP,
                                              update_by bigint,
                                              update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_personnel_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_personnel_t" IS '故障操作人员';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."personnel" IS '人员';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."position" IS '岗位';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."quantity" IS '数量';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."duties" IS '职责';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_personnel_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_equipment_t";
CREATE TABLE "als"."als_fault_equipment_t"(
                                              id bigint NOT NULL,
                                              equipment_code VARCHAR2(255),
                                              equipment_name VARCHAR2(255),
                                              model_number VARCHAR2(255),
                                              quantity INTEGER,
                                              purpose VARCHAR2(255),
                                              remarks VARCHAR2(900),
                                              tenant_id bigint,
                                              version INTEGER,
                                              del_flag bit DEFAULT  0,
                                              create_by bigint,
                                              create_time TIMESTAMP,
                                              update_by bigint,
                                              update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_equipment_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_equipment_t" IS '故障所需设备';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."equipment_code" IS '设备编号';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."equipment_name" IS '设备名称';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."model_number" IS '规格型号';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."quantity" IS '数量';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."purpose" IS '用途';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_equipment_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_spare_parts_t";
CREATE TABLE "als"."als_fault_spare_parts_t"(
                                                id bigint NOT NULL,
                                                spare_parts_code VARCHAR2(255),
                                                spare_parts_name VARCHAR2(255),
                                                model_number VARCHAR2(255),
                                                quantity INTEGER,
                                                purpose VARCHAR2(255),
                                                remarks VARCHAR2(900),
                                                tenant_id bigint,
                                                version INTEGER,
                                                del_flag bit DEFAULT  0,
                                                create_by bigint,
                                                create_time TIMESTAMP,
                                                update_by bigint,
                                                update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_spare_parts_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_spare_parts_t" IS '故障所需备件';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."spare_parts_code" IS '备件编号';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."spare_parts_name" IS '备件名称';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."model_number" IS '规格型号';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."quantity" IS '数量';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."purpose" IS '用途';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_spare_parts_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_consumable_t";
CREATE TABLE "als"."als_fault_consumable_t"(
                                               id bigint NOT NULL,
                                               consumable_name VARCHAR2(255),
                                               quantity INTEGER,
                                               purpose VARCHAR2(255),
                                               remarks VARCHAR2(900),
                                               tenant_id bigint,
                                               version INTEGER,
                                               del_flag bit DEFAULT  0,
                                               create_by bigint,
                                               create_time TIMESTAMP,
                                               update_by bigint,
                                               update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_consumable_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_consumable_t" IS '故障所需耗材';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."consumable_name" IS '耗材名称';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."quantity" IS '数量';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."purpose" IS '用途';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_consumable_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_fault_notes_t";
CREATE TABLE "als"."als_fault_notes_t"(
                                          id bigint NOT NULL,
                                          note_content VARCHAR2(900),
                                          image VARCHAR2(255),
                                          remarks VARCHAR2(900),
                                          tenant_id bigint,
                                          version INTEGER,
                                          del_flag bit DEFAULT  0,
                                          create_by bigint,
                                          create_time TIMESTAMP,
                                          update_by bigint,
                                          update_time TIMESTAMP
);

ALTER TABLE "als"."als_fault_notes_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_fault_notes_t" IS '故障注意事项';
COMMENT ON COLUMN "als"."als_fault_notes_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_fault_notes_t"."note_content" IS '注意内容';
COMMENT ON COLUMN "als"."als_fault_notes_t"."image" IS '图片';
COMMENT ON COLUMN "als"."als_fault_notes_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_fault_notes_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_fault_notes_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_fault_notes_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_fault_notes_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_fault_notes_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_fault_notes_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_fault_notes_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_maintenance_t";
CREATE TABLE "als"."als_maintenance_t"(
                                          id bigint NOT NULL,
                                          aircraft_code VARCHAR2(255),
                                          fault_code VARCHAR2(255),
                                          fault_name VARCHAR2(255),
                                          location VARCHAR2(255),
                                          level VARCHAR2(255),
                                          fault_date DATE,
                                          symptoms VARCHAR2(255),
                                          fault_cause VARCHAR2(255),
                                          status VARCHAR2(255),
                                          supervisor VARCHAR2(255),
                                          maintenance_time TIMESTAMP,
                                          before_equipment_code VARCHAR2(255),
                                          before_equipment_name VARCHAR2(255),
                                          before_model_number VARCHAR2(255),
                                          after_equipment_code_1 VARCHAR2(255),
                                          after_equipment_name_1 VARCHAR2(255),
                                          after_model_number_1 VARCHAR2(255),
                                          quantity VARCHAR2(255),
                                          remarks VARCHAR2(900),
                                          tenant_id bigint,
                                          version INTEGER,
                                          del_flag bit DEFAULT  0,
                                          create_by bigint,
                                          create_time TIMESTAMP,
                                          update_by bigint,
                                          update_time TIMESTAMP
);

ALTER TABLE "als"."als_maintenance_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_maintenance_t" IS '维修信息';
COMMENT ON COLUMN "als"."als_maintenance_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_maintenance_t"."aircraft_code" IS '飞机编码';
COMMENT ON COLUMN "als"."als_maintenance_t"."fault_code" IS '故障代码';
COMMENT ON COLUMN "als"."als_maintenance_t"."fault_name" IS '故障名称';
COMMENT ON COLUMN "als"."als_maintenance_t"."location" IS '故障位置';
COMMENT ON COLUMN "als"."als_maintenance_t"."level" IS '故障等级';
COMMENT ON COLUMN "als"."als_maintenance_t"."fault_date" IS '故障发生时间';
COMMENT ON COLUMN "als"."als_maintenance_t"."symptoms" IS '故障现象';
COMMENT ON COLUMN "als"."als_maintenance_t"."fault_cause" IS '故障原因';
COMMENT ON COLUMN "als"."als_maintenance_t"."status" IS '维修结果';
COMMENT ON COLUMN "als"."als_maintenance_t"."supervisor" IS '维修负责人';
COMMENT ON COLUMN "als"."als_maintenance_t"."maintenance_time" IS '维修时间';
COMMENT ON COLUMN "als"."als_maintenance_t"."before_equipment_code" IS '换件前器材编码';
COMMENT ON COLUMN "als"."als_maintenance_t"."before_equipment_name" IS '换件前器材名称';
COMMENT ON COLUMN "als"."als_maintenance_t"."before_model_number" IS '换件前规格型号';
COMMENT ON COLUMN "als"."als_maintenance_t"."after_equipment_code_1" IS '换件后器材编码';
COMMENT ON COLUMN "als"."als_maintenance_t"."after_equipment_name_1" IS '换件后器材名称';
COMMENT ON COLUMN "als"."als_maintenance_t"."after_model_number_1" IS '换件后规格型号';
COMMENT ON COLUMN "als"."als_maintenance_t"."quantity" IS '更换数量';
COMMENT ON COLUMN "als"."als_maintenance_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_maintenance_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_maintenance_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_maintenance_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_maintenance_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_maintenance_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_maintenance_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_maintenance_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_part_replacement_t";
CREATE TABLE "als"."als_part_replacement_t"(
                                               id bigint NOT NULL,
                                               aircraft_code VARCHAR2(255),
                                               before_equipment_code VARCHAR2(255),
                                               before_equipment_name VARCHAR2(255),
                                               before_model_number VARCHAR2(255),
                                               after_equipment_code VARCHAR2(255),
                                               after_equipment_name VARCHAR2(255),
                                               after_model_number VARCHAR2(255),
                                               quantity VARCHAR2(255),
                                               remarks VARCHAR2(900),
                                               tenant_id bigint,
                                               version INTEGER,
                                               del_flag bit DEFAULT  0,
                                               create_by bigint,
                                               create_time TIMESTAMP,
                                               update_by bigint,
                                               update_time TIMESTAMP
);

ALTER TABLE "als"."als_part_replacement_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_part_replacement_t" IS '换件记录';
COMMENT ON COLUMN "als"."als_part_replacement_t"."id" IS '编号';
COMMENT ON COLUMN "als"."als_part_replacement_t"."aircraft_code" IS '飞机编码';
COMMENT ON COLUMN "als"."als_part_replacement_t"."before_equipment_code" IS '换件前器材编码';
COMMENT ON COLUMN "als"."als_part_replacement_t"."before_equipment_name" IS '换件前器材名称';
COMMENT ON COLUMN "als"."als_part_replacement_t"."before_model_number" IS '换件前规格型号';
COMMENT ON COLUMN "als"."als_part_replacement_t"."after_equipment_code" IS '换件后器材编码';
COMMENT ON COLUMN "als"."als_part_replacement_t"."after_equipment_name" IS '换件后器材名称';
COMMENT ON COLUMN "als"."als_part_replacement_t"."after_model_number" IS '换件后规格型号';
COMMENT ON COLUMN "als"."als_part_replacement_t"."quantity" IS '更换数量';
COMMENT ON COLUMN "als"."als_part_replacement_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_part_replacement_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_part_replacement_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_part_replacement_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_part_replacement_t"."create_by" IS '创建人';
COMMENT ON COLUMN "als"."als_part_replacement_t"."create_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_part_replacement_t"."update_by" IS '更新人';
COMMENT ON COLUMN "als"."als_part_replacement_t"."update_time" IS '更新时间';

DROP TABLE IF EXISTS "als"."als_air_install_t";
CREATE TABLE "als"."als_air_install_t"(
                                          id bigint NOT NULL,
                                          material_code VARCHAR2(255),
                                          material_name VARCHAR2(255),
                                          specs_model VARCHAR2(255),
                                          drawing_number VARCHAR2(255),
                                          category VARCHAR2(255),
                                          quantity VARCHAR2(255),
                                          install_time VARCHAR2(255),
                                          repairable char(1),
                                          complete_set char(1),
                                          service_life char(1),
                                          remarks VARCHAR2(900),
                                          tenant_id bigint,
                                          del_flag bit DEFAULT  0,
                                          version INTEGER,
                                          created_by VARCHAR2,
                                          created_time TIMESTAMP,
                                          updated_by VARCHAR2,
                                          updated_time TIMESTAMP
);

ALTER TABLE "als"."als_air_install_t" ADD CONSTRAINT PRIMARY KEY (id);

COMMENT ON TABLE "als"."als_air_install_t" IS '装机信息';
COMMENT ON COLUMN "als"."als_air_install_t"."id" IS '唯一ID';
COMMENT ON COLUMN "als"."als_air_install_t"."material_code" IS '航材编码';
COMMENT ON COLUMN "als"."als_air_install_t"."material_name" IS '航材名称';
COMMENT ON COLUMN "als"."als_air_install_t"."specs_model" IS '规格型号';
COMMENT ON COLUMN "als"."als_air_install_t"."drawing_number" IS '图号';
COMMENT ON COLUMN "als"."als_air_install_t"."category" IS '所属分类';
COMMENT ON COLUMN "als"."als_air_install_t"."quantity" IS '装机数量';
COMMENT ON COLUMN "als"."als_air_install_t"."install_time" IS '装机时间';
COMMENT ON COLUMN "als"."als_air_install_t"."repairable" IS '是否可修';
COMMENT ON COLUMN "als"."als_air_install_t"."complete_set" IS '是否成套';
COMMENT ON COLUMN "als"."als_air_install_t"."service_life" IS '是否有寿';
COMMENT ON COLUMN "als"."als_air_install_t"."remarks" IS '备注';
COMMENT ON COLUMN "als"."als_air_install_t"."tenant_id" IS '租户号';
COMMENT ON COLUMN "als"."als_air_install_t"."del_flag" IS '删除标识（1删除 0未删除）';
COMMENT ON COLUMN "als"."als_air_install_t"."version" IS '乐观锁';
COMMENT ON COLUMN "als"."als_air_install_t"."created_by" IS '创建人';
COMMENT ON COLUMN "als"."als_air_install_t"."created_time" IS '创建时间';
COMMENT ON COLUMN "als"."als_air_install_t"."updated_by" IS '更新人';
COMMENT ON COLUMN "als"."als_air_install_t"."updated_time" IS '更新时间';
